==> fwbuilder_5.0.0.orig.tar.gz: fwbuilder-5.0.0.3568/src/libfwbuilder/src/fwbuilder/physAddress.h <==
/* 

                          Firewall Builder

                 Copyright (C) 2002 NetCitadel, LLC

  Author:  Vadim Kurland <vadim@fwbuilder.org>

  $Id$

  This program is free software which we release under the GNU General Public
  License. You may redistribute and/or modify this program under the terms
  of that license as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  To get a copy of the GNU General Public License, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/


#ifndef __PHYS_ADDRESS_HH_FLAG__
#define __PHYS_ADDRESS_HH_FLAG__

#include <fwbuilder/FWObject.h>
#include <fwbuilder/Address.h>
#include <fwbuilder/ObjectMatcher.h>

namespace libfwbuilder
{

class physAddress : public Address
{
    private:
    
    public:

    DECLARE_FWOBJECT_SUBTYPE(physAddress);

    DECLARE_DISPATCH_METHODS(physAddress);
    
    physAddress();

    virtual void fromXML(xmlNodePtr parent) throw(FWException);
    virtual xmlNodePtr toXML(xmlNodePtr xml_parent_node) throw(FWException);

    std::string getPhysAddress() const;
    void setPhysAddress(const std::string &s);

    virtual FWReference* createRef();

    bool isAny() const;

    virtual bool isPrimaryObject() const { return false; }

};

}


#endif

==> fwbuilder_5.1.0.orig.tar.gz: fwbuilder-5.1.0.3599/src/libfwbuilder/src/fwbuilder/physAddress.h <==
/* 

                          Firewall Builder

                 Copyright (C) 2002 NetCitadel, LLC

  Author:  Vadim Kurland <vadim@fwbuilder.org>

  $Id$

  This program is free software which we release under the GNU General Public
  License. You may redistribute and/or modify this program under the terms
  of that license as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  To get a copy of the GNU General Public License, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/


#ifndef __PHYS_ADDRESS_HH_FLAG__
#define __PHYS_ADDRESS_HH_FLAG__

#include "fwbuilder/FWObject.h"
#include "fwbuilder/Address.h"
#include "fwbuilder/ObjectMatcher.h"

namespace libfwbuilder
{

class physAddress : public Address
{
    private:
    
    public:

    DECLARE_FWOBJECT_SUBTYPE(physAddress);

    DECLARE_DISPATCH_METHODS(physAddress);
    
    physAddress();

    virtual void fromXML(xmlNodePtr parent) throw(FWException);
    virtual xmlNodePtr toXML(xmlNodePtr xml_parent_node) throw(FWException);

    std::string getPhysAddress() const;
    void setPhysAddress(const std::string &s);

    virtual FWReference* createRef();

    bool isAny() const;

    virtual bool isPrimaryObject() const { return false; }

};

}


#endif
